@@ -19,7 +19,7 @@ import pandas as pd
 from termcolor import cprint
 from inspect import currentframe
 
-__version__ = '0.1.25'
+__version__ = '0.1.26'
 
 __info__ = {
     '2022/01/04: 0.1.18 加入 __info__。',
@@ -605,7 +605,11 @@ class tplaysound(threading.Thread):
 
         self.queue = queue.Queue()
 
-        self.sound_alert = f'{_MYPYLIB_ROOT}/sound/alert.wav'
+        self.sound_alert = f'{_MYPYLIB_ROOT}/../data/alert.wav'
+
+        self.start()
+
+
 
     def play_file(self, filename=None):
         if filename is None:
@@ -644,7 +648,6 @@ if __name__ == '__main__':
 
     if True:
         tps = tplaysound()
-        tps.start()
         index = 0
         while True:
             tps.play_file()
